@@ -7,7 +7,7 @@ use Socket;
 use Carp qw(carp croak);
 use vars qw($VERSION);
 
-$VERSION = '0.08';
+$VERSION = '0.10';
 
 sub spawn {
   my $package = shift;
@@ -63,6 +63,12 @@ sub connect {
   $poe_kernel->call( $self->{session_id}, 'connect' );
 }
 
+sub wheel {
+  my $self = shift;
+  return unless $self->{socket};
+  return $self->{socket};
+}
+
 sub _start {
   my ($kernel,$self,$sender,$autoconnect) = @_[KERNEL,OBJECT,SENDER,ARG0];
   $self->{session_id} = $_[SESSION]->ID();
@@ -229,7 +235,7 @@ sub _test_filter {
 
 sub _socket_fail {
   my ($kernel,$self,$operation,$errnum,$errstr,$wheel_id) = @_[KERNEL,OBJECT,ARG0..ARG3];
-  carp "Wheel $wheel_id generated $operation error $errnum: $errstr\n";
+  carp "Wheel $wheel_id generated $operation error $errnum: $errstr\n" if $self->{debug};
   delete $self->{factory};
   $self->_send_event( $self->{_prefix} . 'socket_failed', $operation, $errnum, $errstr );
   return;
@@ -644,6 +650,11 @@ using C<send_to_server()> and the server connection will be terminated.
 
 Immediately disconnects a server conenction.
 
+=item C<wheel>
+
+Returns the underlying L<POE::Wheel::ReadWrite> object if we are currently connected to a server, C<undef> otherwise.
+You can use this method to call methods on the wheel object to switch filters, etc. Exercise caution.
+
 =back
 
 =head1 INPUT EVENTS
